@@ -4,9 +4,7 @@
 
 
 from django.test.runner import DiscoverRunner
-from .result import TestResult, DebugSQLTestResult, PDBDebugResult
-
-# TODO RPC METHOD: <Fault -32601: 'Method not found: "PlanType.create"'>
+from .result import TestResult, DebugSQLTestResult
 
 
 class TestRunner(DiscoverRunner):
@@ -15,7 +13,4 @@ class TestRunner(DiscoverRunner):
         if self.debug_sql:
             return DebugSQLTestResult
 
-        if self.pdb:
-            return PDBDebugResult
-
         return TestResult
